NAME
Jifty::Action::Autocomplete
DESCRIPTION
A built-in Jifty::Action which returns suggested autocompletions for a given argument of an action. Generally this is called by Jifty's internals through /__jifty/autocomplete.xml.
This action gets its data to /__jifty/autocomplete.xml by filling in the completions of the "content" in Jifty::Result.
arguments
The arguments for Autocomplete are:
- action
-
The moniker of an action we want to pull a field to autocomplete from.
- argument
-
The fully qualified name of the argument to
actionthat we want to complete.
take_action
Find the submitted action in the Jifty::Request named by the action above, and ask it for autocompletion possibilites for the argument in question.